{
    "class": "Workflow",
    "requirements": [
        {
            "envDef": [
                {
                    "envValue": "abc",
                    "envName": "SCIHUB_PW"
                },
                {
                    "envValue": "xyz",
                    "envName": "SCIHUB_UN"
                }
            ],
            "class": "EnvVarRequirement"
        },
        {
            "ramMin": 4000,
            "ramMax": 12000,
            "class": "ResourceRequirement"
        },
        {
            "class": "ScatterFeatureRequirement"
        },
        {
            "class": "SubworkflowFeatureRequirement"
        }
    ],
    "inputs": [
        {
            "type": "string",
            "id": "#main/areaOfInterest"
        },
        {
            "type": "string",
            "id": "#main/endDate"
        },
        {
            "type": "string",
            "id": "#main/startDate"
        }
    ],
    "steps": [
        {
            "run": {
                "class": "CommandLineTool",
                "baseCommand": "papermill",
                "hints": [
                    {
                        "dockerPull": "workflow_water_masks_nb2classify:latest",
                        "class": "DockerRequirement"
                    }
                ],
                "requirements": [
                    {
                        "ramMin": 4000,
                        "ramMax": 12000,
                        "class": "ResourceRequirement"
                    }
                ],
                "arguments": [
                    "/nb2.ipynb",
                    "out.ipynb",
                    "-p",
                    "sentinel_ids",
                    "$(inputs.sentinelSceneIds)",
                    "-p",
                    "REQUEST_AREA",
                    "$(inputs.areaOfInterest)"
                ],
                "inputs": [
                    {
                        "type": "string",
                        "id": "#main/classify/f48b9b60-fb40-429c-a9bc-62b118b0329e/areaOfInterest"
                    },
                    {
                        "type": "string",
                        "id": "#main/classify/f48b9b60-fb40-429c-a9bc-62b118b0329e/sentinelSceneIds"
                    }
                ],
                "outputs": [
                    {
                        "outputBinding": {
                            "glob": "result.tif"
                        },
                        "streamable": false,
                        "type": "File",
                        "id": "#main/classify/f48b9b60-fb40-429c-a9bc-62b118b0329e/floodmask"
                    }
                ],
                "id": "#main/classify/f48b9b60-fb40-429c-a9bc-62b118b0329e"
            },
            "scatter": "#main/classify/sentinelSceneIds",
            "in": [
                {
                    "source": "#main/areaOfInterest",
                    "id": "#main/classify/areaOfInterest"
                },
                {
                    "source": "#main/discover_parse/sentinelIds",
                    "id": "#main/classify/sentinelSceneIds"
                }
            ],
            "out": [
                "#main/classify/floodmask"
            ],
            "id": "#main/classify"
        },
        {
            "in": [
                {
                    "source": "#main/areaOfInterest",
                    "id": "#main/discover/areaOfInterest"
                },
                {
                    "source": "#main/endDate",
                    "id": "#main/discover/endDate"
                },
                {
                    "source": "#main/startDate",
                    "id": "#main/discover/startDate"
                }
            ],
            "out": [
                "#main/discover/nb1_out"
            ],
            "run": {
                "class": "CommandLineTool",
                "baseCommand": "papermill",
                "hints": [
                    {
                        "dockerPull": "workflow_water_masks_nb1request:latest",
                        "class": "DockerRequirement"
                    }
                ],
                "inputs": [
                    {
                        "type": "string",
                        "id": "#main/discover/f2e9dc0b-7243-4935-904b-b20c60bd9b3a/areaOfInterest"
                    },
                    {
                        "type": "string",
                        "id": "#main/discover/f2e9dc0b-7243-4935-904b-b20c60bd9b3a/endDate"
                    },
                    {
                        "type": "string",
                        "id": "#main/discover/f2e9dc0b-7243-4935-904b-b20c60bd9b3a/startDate"
                    }
                ],
                "arguments": [
                    "/nb1.ipynb",
                    "out.ipynb",
                    "-p",
                    "REQUEST_AREA",
                    "$(inputs.areaOfInterest)",
                    "-p",
                    "START_DATE",
                    "$(inputs.startDate)",
                    "-p",
                    "END_DATE",
                    "$(inputs.endDate)"
                ],
                "outputs": [
                    {
                        "type": "File",
                        "outputBinding": {
                            "glob": "out.ipynb"
                        },
                        "id": "#main/discover/f2e9dc0b-7243-4935-904b-b20c60bd9b3a/nb1_out"
                    }
                ],
                "id": "#main/discover/f2e9dc0b-7243-4935-904b-b20c60bd9b3a"
            },
            "id": "#main/discover"
        },
        {
            "in": [
                {
                    "source": "#main/discover/nb1_out",
                    "id": "#main/discover_parse/input_nb"
                }
            ],
            "out": [
                "#main/discover_parse/sentinelIds"
            ],
            "run": {
                "class": "CommandLineTool",
                "hints": [
                    {
                        "dockerPull": "workflow_water_masks_nb1request:latest",
                        "class": "DockerRequirement"
                    }
                ],
                "baseCommand": [
                    "python3",
                    "parse.py"
                ],
                "requirements": [
                    {
                        "listing": [
                            {
                                "entryname": "parse.py",
                                "entry": "import scrapbook as sb\nnb = sb.read_notebook(\"$(inputs.input_nb.path)\")\nprint(','.join(list(nb.scrap_dataframe[\"data\"])[0]))\n"
                            }
                        ],
                        "class": "InitialWorkDirRequirement"
                    },
                    {
                        "class": "InlineJavascriptRequirement"
                    }
                ],
                "stdout": "csvItems",
                "inputs": [
                    {
                        "type": "File",
                        "id": "#main/discover_parse/f5b2910a-26af-4003-bdcb-061720002276/input_nb"
                    }
                ],
                "outputs": [
                    {
                        "type": {
                            "type": "array",
                            "items": "string"
                        },
                        "outputBinding": {
                            "glob": "csvItems",
                            "loadContents": true,
                            "outputEval": "$(self[0].contents.replace('\\n','').split(','))"
                        },
                        "id": "#main/discover_parse/f5b2910a-26af-4003-bdcb-061720002276/sentinelIds"
                    }
                ],
                "id": "#main/discover_parse/f5b2910a-26af-4003-bdcb-061720002276"
            },
            "id": "#main/discover_parse"
        },
        {
            "run": {
                "class": "CommandLineTool",
                "baseCommand": "papermill",
                "requirements": [
                    {
                        "class": "InlineJavascriptRequirement"
                    }
                ],
                "hints": [
                    {
                        "dockerPull": "workflow_water_masks_nb3aggregate:latest",
                        "class": "DockerRequirement"
                    }
                ],
                "arguments": [
                    "/nb3.ipynb",
                    "out.ipynb"
                ],
                "inputs": [
                    {
                        "type": {
                            "type": "array",
                            "items": "File"
                        },
                        "inputBinding": {
                            "prefix": "-y",
                            "valueFrom": "${\n  var yml = \"floodmasks_geotiff: [\"\n  self.forEach(function(file){\n    yml = yml + file.path + \",\"\n  })\n  yml = yml + \"]\"\n  return yml\n}\n"
                        },
                        "streamable": false,
                        "id": "#main/mosaic/8c010ef2-0e0c-4fd0-b4f0-714e99917352/floodmasks_geotiff_as_array"
                    }
                ],
                "outputs": [
                    {
                        "outputBinding": {
                            "glob": "mosaic.tif"
                        },
                        "streamable": false,
                        "type": "File",
                        "id": "#main/mosaic/8c010ef2-0e0c-4fd0-b4f0-714e99917352/floodmask_mosaic"
                    }
                ],
                "id": "#main/mosaic/8c010ef2-0e0c-4fd0-b4f0-714e99917352"
            },
            "in": [
                {
                    "source": "#main/classify/floodmask",
                    "id": "#main/mosaic/floodmasks_geotiff_as_array"
                }
            ],
            "out": [
                "#main/mosaic/floodmask_mosaic"
            ],
            "id": "#main/mosaic"
        }
    ],
    "id": "#main",
    "outputs": [
        {
            "type": "File",
            "streamable": false,
            "outputSource": "#main/mosaic/floodmask_mosaic",
            "id": "#main/floodmask_mosaic"
        }
    ],
    "cwlVersion": "v1.0"
}
